<?php

namespace App\Modules\Billing\Http\Controllers;

use Illuminate\Http\Request;

use App\Http\Requests;
use App\Http\Controllers\Controller;
use Carbon\Carbon;
/*This below line code is used fo getting charges model*/
use App\Modules\Billing\Models\Charges;
use Illuminate\Support\Facades\Validator;
use Illuminate\Validation\Rule;
use Illuminate\Support\Facades\DB;

class ChargeController extends Controller
{
	/*This function is used for getting Charges/charge */
    public function getCharges($id='', Request $request)
	{
		/*This below condition is used for distinguish edit Charge request, In this case we get details of particular charge */
        if($id > 0){
            return Charges::find($id);
        }
        /*This below condition is used for distinguish search form request, */
        if($request->has('search')){
            return Charges::where('charge_type', 'LIKE', '%' . $request->search . '%')->where('status','!=',0)->paginate(10);
        }
        /*This below condition is used for distinguish getting all data list form request, */
        if($request->has('datalist')){
            return Charges::whereNotIn('status', [0,'2'])->get();
        }
        return Charges::where('status','!=',0)->paginate(10);
	}
	/*This below function is used for delete a particulate Change from list  */
	public function deleteCharge($id='', Request $request){
		//$form = new form();
		Charges::where('id', $id)->update(['status'=>0]);
		return array('error' => false, 'charges' => 'Charge Deleted successfully');
		//;
	}
	/*This below function is used for Add new record in database */
	public function addCharge(Request $request){
		$id = 0;
         if($request->id > 0 ){
            $id = $request->id;
         }
		$validator = Validator::make($request->all(), [
			'charge_type' => 'required',
			'charge_cost' => 'required|numeric',
			'charge_code' => [
                'required',
                'min:1',
                'max:4',
                Rule::unique('charges')->where(function ($query) use($id) {
                    $query->where('status','!=',0)->where('id','!=',$id);
                })
            ],
			'status' => 'required'
			
		]);
		//'doctor_related' => 'required',
		//if validation fails
		if ($validator->fails()) {
			return array(
				'error' => true,
				'message' => $validator->errors()
			);
		}
		//creating a new Charge model object
		$charges = new Charges();
		$charges->charge_type = $request->charge_type;
		$charges->charge_cost = $request->charge_cost;
		$charges->charge_code = $request->charge_code;
		$charges->doctor_related = filter_var($request->doctor_related, FILTER_VALIDATE_BOOLEAN);
		$charges->description = $request->description;
		$charges->status = $request->status;
		//this below condition block is used for update records in database 
		if((isset($request->id)) && ($request->id > 0)) {
			$item = $charges->findOrFail($request->id)->where('status','!=',0);
			if($item){
				$modification_date =  Carbon::now('Asia/Kolkata');
				$charges->where('id', $request->id)->update(['charge_type'=>$charges->charge_type,'charge_cost'=>$charges->charge_cost, 'charge_code'=>$charges->charge_code,'doctor_related'=>$charges->doctor_related,'description'=>$charges->description,'status'=>$charges->status,'modification_date'=>$modification_date]);
			   // return $item;
				return array('error' => false, 'charges' => 'Charge Updated successfully');
			}
		}
		//saving the Charge to database
		$charges->save();
	//	return $charges->toSql();
		return array('error' => false, 'charges' => 'Charge added successfully');
	}

	//This below function used for getting All Charges related to doctors
	public function getDrCharge(Request $request){
		return Charges::whereNotIn('status', [0,'2'])->where('doctor_related', 1)->get();
	}
}
